summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/effects.cc
diff options
context:
space:
mode:
authorDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-10-31 07:58:11 -0500
committerDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-10-31 07:58:51 -0500
commit6a275792790c00018e47769a05022a42a5498039 (patch)
tree60646cabf825cc211655b78cd9381fbde0f7e6b5 /crawl-ref/source/effects.cc
parent4f4bf0d17aebc565663ee098610e5c2ed86654b6 (diff)
downloadcrawl-ref-6a275792790c00018e47769a05022a42a5498039.tar.gz
crawl-ref-6a275792790c00018e47769a05022a42a5498039.zip
Add more minor cosmetic fixes.
Diffstat (limited to 'crawl-ref/source/effects.cc')
-rw-r--r--crawl-ref/source/effects.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/crawl-ref/source/effects.cc b/crawl-ref/source/effects.cc
index 9cf8840c41..6f64234350 100644
--- a/crawl-ref/source/effects.cc
+++ b/crawl-ref/source/effects.cc
@@ -1209,10 +1209,10 @@ static armour_type _acquirement_armour_subtype(bool divine)
}
// If armour acquirement turned up a non-ego non-artefact armour item,
-// see whether the player has any unfilled equipment slots. If so,
-// hand out a mundane (and possibly negatively enchanted) item of that
-// type. Otherwise, keep the original armour.
-static bool _try_give_mundane_armour(item_def &arm)
+// see whether the player has any unfilled equipment slots. If so,
+// hand out a plain (and possibly negatively enchanted) item of that
+// type. Otherwise, keep the original armour.
+static bool _try_give_plain_armour(item_def &arm)
{
static const equipment_type armour_slots[] =
{ EQ_SHIELD, EQ_CLOAK, EQ_HELMET, EQ_GLOVES, EQ_BOOTS };
@@ -1951,7 +1951,7 @@ int acquirement_create_item(object_class_type class_wanted,
item_def &doodad(mitm[thing_created]);
// For mundane armour, try to change the subtype to something
// matching a currently unfilled equipment slot.
if (doodad.base_type == OBJ_ARMOUR && !is_artefact(doodad))
{
@@ -1985,7 +1985,7 @@ int acquirement_create_item(object_class_type class_wanted,
if (is_plain || is_redundant)
{
- if (_try_give_mundane_armour(doodad))
+ if (_try_give_plain_armour(doodad))
{
// Make sure the item is plain.
doodad.special = SPARM_NORMAL;
@@ -1951,7 +1951,7 @@ int acquirement_create_item(object_class_type class_wanted,
item_def &doodad(mitm[thing_created]);
- // For mundane armour, try to change the subtype to something
+ // For plain armour, try to change the subtype to something
// matching a currently unfilled equipment slot.
if (doodad.base_type == OBJ_ARMOUR && !is_artefact(doodad))